AndroidSmartAppUpdate class

A Flutter plugin for handling in-app updates using Google Play Core API.

This plugin provides methods to check for app updates, start immediate or flexible updates, and track update progress.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

completeFlexibleUpdate() Future<bool>
Completes a flexible update by installing the downloaded update.
isUpdateAvailable() Future<bool>
Checks if an app update is available.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onProgressUpdated(dynamic callback(SmartAppUpdateProgressInfo)) → void
Sets a callback to receive update progress notifications.
startFlexibleUpdate() Future<bool>
Starts a flexible update flow.
startImmediateUpdate() Future<bool>
Starts an immediate update flow.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance AndroidSmartAppUpdate
Gets the singleton instance of SmartAppUpdate
no setter