SmartAppUpdate class

Constructors

SmartAppUpdate({String? iOSAppStoreCountry, String? iOSId, required String iOSAppLinkUrl})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
iOSAppLinkUrl String
final
iOSAppStoreCountry String?
Only affects iOS App Store lookup: The two-letter country code for the store you want to search. Provide a value here if your app is only available outside the US. For example: US. The default is US. See http://en.wikipedia.org/wiki/ ISO_3166-1_alpha-2 for a list of ISO Country Codes.
final
iOSId String?
An optional value that can override the default packageName when attempting to reach the Apple App Store. This is useful if your app has a different package name in the App Store.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

completeFlexibleUpdate() Future<bool>
Completes a flexible update by installing the downloaded update.
getUpdateInfo() Future<SmartAppUpdateDetails>
Checks if an app update is available.
handleUpdateProgress({required SmartAppUpdateProgressInfo progressInfo}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startFlexibleUpdateIfAvailable() Future<bool>
Starts a flexible update flow.
startImmediateUpdateIfAvailable() Future<bool>
Starts an immediate update flow.
toString() String
A string representation of this object.
inherited
updateIfAvailable({bool isFlexibleUpdateAndroid = true, Widget iOSUpdateDialogBuilder()?, BuildContext? contextBuilder()?, void androidProgressCallback(SmartAppUpdateProgressInfo)?}) Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited