IOSSmartAppUpdate class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getUpdateInfo(
{String? iOSAppStoreCountry, String? iOSId}) → Future< SmartAppUpdateDetails?> - iOS info is fetched by using the iTunes lookup API, which returns a JSON document.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openAppStore(
{required String appLinkUrl}) → Future< bool> -
showUpdateDialog(
{required BuildContext? contextBuilder()?, required String appLinkUrl, required String? releaseNotes}) → Future< bool> -
showUpdateDialogWithBuilder(
{required BuildContext? contextBuilder()?, required Widget iOSUpdateDialogBuilder()}) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → IOSSmartAppUpdate
-
Gets the singleton instance of SmartAppUpdate
no setter